<!DOCTYPE html>
<html lang="en">
  <head>
    <script>
      // Hack for scrolling window when linking to anchor tag with fixed nav header
      var shiftWindow = function() { scrollBy(0, -75) };
      window.addEventListener("hashchange", shiftWindow);
      function load() { if (window.location.hash) shiftWindow(); }
    </script>
    {%- block site_meta %}
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    {% if page and page.is_homepage %}<meta name="description" content="{{ config['site_description'] }}">{% endif %}
    {% if config.site_author %}<meta name="author" content="{{ config.site_author }}">{% endif %}
    {% if page and page.canonical_url %}<link rel="canonical" href="{{ page.canonical_url }}">{% endif %}
    {% if config.site_favicon %}<link rel="shortcut icon" href="{{ config.site_favicon|url }}">
    {% else %}<link rel="shortcut icon" href="{{ 'img/favicon.ico'|url }}">{% endif %}
    {%- endblock %}
    
    {%- block htmltitle %}
    <title>{% if page and page.title and not page.is_homepage %}{{ page.title }} - {% endif %}{{ config.site_name }}</title>
    {%- endblock %}
    
    {%- block styles %}
    <link href="https://stackpath.bootstrapcdn.com/bootstrap/4.3.1/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://fonts.googleapis.com/icon?family=Material+Icons" rel="stylesheet">
    <link href="https://cdn.rawgit.com/afeld/bootstrap-toc/v1.0.1/dist/bootstrap-toc.min.css" rel="stylesheet">
    <link href="{{ "css/code-styles.css"|url }}" rel="stylesheet">
    <link href="{{ "css/code-tabs.css"|url }}" rel="stylesheet">
    <link href="{{ "css/admonition.css"|url }}" rel="stylesheet">
    <link href="{{ "css/base.css"|url }}" rel="stylesheet">
    <link href="{{ "css/ringcentral.css"|url }}" rel="stylesheet">
    {%- if page and page.meta.swagger_scripts_enabled %}
    <link href="https://cdnjs.cloudflare.com/ajax/libs/swagger-ui/3.43.0/swagger-ui.css" rel="stylesheet">
    {%- endif %}
    {%- for path in config['extra_css'] %}
    <link href="{{ path|url }}" rel="stylesheet">
    {%- endfor %}
    {%- endblock %}
    
    {%- block libs %}
    <!-- HTML5 shim and Respond.js IE8 support of HTML5 elements and media queries -->
    <!--[if lt IE 9]>
        <script src="https://oss.maxcdn.com/libs/html5shiv/3.7.0/html5shiv.js"></script>
        <script src="https://oss.maxcdn.com/libs/respond.js/1.4.2/respond.min.js"></script>
    <![endif]-->
    <script src="https://code.jquery.com/jquery-3.3.1.slim.min.js"></script>
    <script src="{{ "fonts.js"|url }}"></script>
    <script src="https://kit.fontawesome.com/2a3737b952.js" crossorigin="anonymous"></script>
    {%- endblock %}
    
    {%- block analytics %}
    {%- if config.google_analytics %}
    <script>
      (function(i,s,o,g,r,a,m){i['GoogleAnalyticsObject']=r;i[r]=i[r]||function(){
          (i[r].q=i[r].q||[]).push(arguments)},i[r].l=1*new Date();a=s.createElement(o),
			       m=s.getElementsByTagName(o)[0];a.async=1;a.src=g;m.parentNode.insertBefore(a,m)
			      })(window,document,'script','https://www.google-analytics.com/analytics.js','ga');
      
      ga('create', '{{ config.google_analytics[0] }}', '{{ config.google_analytics[1] }}');
      ga('send', 'pageview');
    </script>
    {%- endif %}
    {%- endblock %}
    
    {%- block extrahead %} {% endblock %}
  </head>
  
  <body class="{{ config.theme.product_section }} {% if page and page.is_homepage %}homepage {% endif %}{%- if page and page.meta.jumbotron -%}has-jumbotron {%- endif -%}{%- if page and page.meta.style %}{{ page.meta.style }}{% endif %}{%- if page and page.meta.swagger_scripts_enabled %} swagger-ui{%- endif -%}" data-spy="scroll" data-target="#toc">
    {% include "main-nav.html" %}
    {%- set main_content %}
    <div class="row flex-nowrap">
      {%- if page and page.meta.no_sidenav -%}{% else %}<div id="sidebar-nav" class="sidebar col-md-3">{% include "side-nav.html" %}</div>{%- endif -%}
      <div id="main" class="{%- if config.theme.fluid_layout -%}col{%- else -%}col-md-8{%- endif -%}" role="main">{% include "content.html" %}</div>
      <div id="sidebar-toc" class="sidebar col-md-3">
        <div class="repo">
            {%- block repo %}
            {%- if page and page.edit_url %}
              <a class="nav-link" href="{{ page.edit_url }}">
		{%- if config.repo_name == 'GitHub' -%}
		<i class="fa fa-github"></i> Edit on {{ config.repo_name }}
		{%- elif config.repo_name == 'Bitbucket' -%}
		<i class="fa fa-bitbucket"></i> Edit on {{ config.repo_name }}
		{%- elif config.repo_name == 'GitLab' -%}
		<i class="fa fa-gitlab"></i> Edit on {{ config.repo_name }}
		{%- else -%}
		Edit on {{ config.repo_name }}
		{%- endif -%}
              </a>
            {%- elif config.repo_url %}
              <a class="nav-link" href="{{ config.repo_url }}">
		{%- if config.repo_name == 'GitHub' -%}
		<i class="fa fa-github"></i> {{ config.repo_name }}
		{%- elif config.repo_name == 'Bitbucket' -%}
		<i class="fa fa-bitbucket"></i> {{ config.repo_name }}
		{%- elif config.repo_name == 'GitLab' -%}
		<i class="fa fa-gitlab"></i> {{ config.repo_name }}
		{%- else -%}
		{{ config.repo_name }}
		{%- endif -%}
              </a>
            {%- endif %}
            {%- endblock %}
        </div>

        {% if page and not page.meta.no_rating %}
        <div id="rating" class="nav-link">&#9733;&#9733;&#9733;&#9733;&#9733;</div>
        {% endif %}

	<nav id="toc" data-toggle="toc" class="sticky-top sticky-offset"></nav>
      </div>

    </div>
    {%- endset %}
    
    {%- block content %}
    {%- if page and page.meta.jumbotron -%}
    <div class="jumbotron">
      <div class="container">
        {{- page.meta.jumbotron_content -}}
      </div>
    </div>
    {%- endif -%}
    {%- endblock %}
    <div id="content"{%- if not config.theme.fluid_layout -%} class="container"{%- else -%} class="container-fluid"{%- endif -%}>
      {{ main_content }}
    </div>
    
    {%- include "footer.html" -%}
    
    {%- block scripts %}
    <script>
      var base_url = {{ base_url | tojson }},
          shortcuts = {{ config.theme.shortcuts | tojson }};
    </script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.14.3/umd/popper.min.js" defer></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.3.1/js/bootstrap.min.js" defer></script>
    <script src="https://cdn.rawgit.com/afeld/bootstrap-toc/v1.0.1/dist/bootstrap-toc.min.js" defer></script>
    {%- if page and page.meta.swagger_scripts_enabled %}
    <script src="https://cdnjs.cloudflare.com/ajax/libs/swagger-ui/3.43.0/swagger-ui-bundle.js"> </script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/swagger-ui/3.43.0/swagger-ui-standalone-preset.js"> </script>
    {%- endif %}
    {%- for path in config['extra_javascript'] %}
    <script src="{{ path|url }}"></script>
    {%- endfor %}
    <script src="{{ "js/base.js"|url }}" defer></script>
    {%- endblock %}

    {% if 'search' in config['plugins'] %}{%- include "search-modal.html" %}{% endif %}
    {%- include "keyboard-modal.html" %}
    
  </body>
</html>
{% if page and page.is_homepage %}
<!--
    MkDocs version : {{ mkdocs_version }}
    Build Date UTC : {{ build_date_utc }}
-->
{% endif %}
